@@ -25,7 +25,7 @@ local m = {}
 ---@return uri uri
 function m.encode(path)
     local authority = ''
-    if platform.OS == 'Windows' then
+    if platform.os == 'windows' then
         path = path:gsub('\\', '/')
     end
 
@@ -49,7 +49,7 @@ function m.encode(path)
 
     --lower-case windows drive letters in /C:/fff or C:/fff
     local start, finish, drive = path:find '/(%u):'
-    if drive then
+    if drive and finish then
         path = path:sub(1, start) .. drive:lower() .. path:sub(finish, -1)
     end
 
@@ -82,7 +82,7 @@ function m.decode(uri)
     else
         value = path
     end
-    if platform.OS == 'Windows' then
+    if platform.os == 'windows' then
         value = value:gsub('/', '\\')
     end
     return value
@@ -92,8 +92,24 @@ function m.split(uri)
     return uri:match('([^:]*):/?/?([^/]*)(.*)')
 end
 
+---@param uri string
+---@return boolean
+function m.isValid(uri)
+    local scheme, authority, path = m.split(uri)
+    if not scheme or scheme == '' then
+        return false
+    end
+    if path == '' then
+        return false
+    end
+    if scheme ~= 'file' then
+        return false
+    end
+    return true
+end
+
 function m.normalize(uri)
-    if uri == '' then
+    if not m.isValid(uri) then
         return uri
     end
     return m.encode(m.decode(uri))
